package com.fs.hospital.service;

import java.util.List;

import com.fs.common.core.domain.R;
import com.fs.hospital.domain.HospitalMemberRecharge;

/**
 * 用户充值Service接口
 *
 * @author fs
 * @date 2024-03-04
 */
public interface IHospitalMemberRechargeService
{
    /**
     * 查询用户充值
     *
     * @param rechargeId 用户充值主键
     * @return 用户充值
     */
    public HospitalMemberRecharge selectHospitalMemberRechargeByRechargeId(Long rechargeId);

    /**
     * 查询用户充值列表
     *
     * @param hospitalMemberRecharge 用户充值
     * @return 用户充值集合
     */
    public List<HospitalMemberRecharge> selectHospitalMemberRechargeList(HospitalMemberRecharge hospitalMemberRecharge);

    /**
     * 新增用户充值
     *
     * @param hospitalMemberRecharge 用户充值
     * @return 结果
     */
    public R insertHospitalMemberRecharge(HospitalMemberRecharge hospitalMemberRecharge);

    /**
     * 修改用户充值
     *
     * @param hospitalMemberRecharge 用户充值
     * @return 结果
     */
    public int updateHospitalMemberRecharge(HospitalMemberRecharge hospitalMemberRecharge);

    /**
     * 批量删除用户充值
     *
     * @param rechargeIds 需要删除的用户充值主键集合
     * @return 结果
     */
    public int deleteHospitalMemberRechargeByRechargeIds(Long[] rechargeIds);

    /**
     * 删除用户充值信息
     *
     * @param rechargeId 用户充值主键
     * @return 结果
     */
    public int deleteHospitalMemberRechargeByRechargeId(Long rechargeId);
}
